<?php

/**
 * This file contains QUI\Pace\EventHandler
 */

namespace QUI\Pace;

/**
 * Class EventHandler
 * @package QUI\Pace
 */
class EventHandler
{
    /**
     * Event : on smarty init
     * @param \Smarty $Smarty - \Smarty
     */
    public static function onSmartyInit($Smarty)
    {
        // {pace}
        if (
            !isset($Smarty->registered_plugins['function']) ||
            !isset($Smarty->registered_plugins['function']['pace'])
        ) {
            $Smarty->registerPlugin(
                "function",
                "pace",
                "\\QUI\\Pace\\EventHandler::pace"
            );
        }
    }

    /**
     * Smarty brickarea function {brickarea}
     *
     * @param array $params - function parameter
     * @param \Smarty $smarty - \Smarty
     * @return array|String
     */
    public static function pace($params, $smarty)
    {
        $theme = 'red/pace-theme-minimal.css';

        if (isset($params['theme'])) {
            $theme = $params['theme'];
        }

        $themeRealPath = OPT_DIR . 'bin/quiqqer-asset/pace-js/pace-js/themes/' . $theme;

        if (file_exists($themeRealPath)) {
            $themePath = URL_OPT_DIR . 'bin/quiqqer-asset/pace-js/pace-js/themes/' . $theme;
        } else {
            $themePath = URL_OPT_DIR . 'bin/quiqqer-asset/pace-js/pace-js/themes/red/pace-theme-minimal.css';
        }


        return '
            <script src="' . URL_OPT_DIR . 'bin/quiqqer-asset/pace-js/pace-js/pace.min.js"></script>
            <link href="' . $themePath . '" rel="stylesheet"/>
            <script>
                if (typeof Pace !== "undefined") {
                    Pace.on("done", function() {
                        setTimeout(function() {
                            if (document.body.className.indexOf("pace-done") !== -1) {
                                document.body.classList.remove("pace-done");
                                document.body.classList.add("pace-done"); // only one pace-done class
                            }
                        }, 300);
                    });
                }
            </script>
        ';
    }
}
